@@ -15,10 +15,11 @@ limitations under the License.
 
 """
 
-import falcon
-from six import iteritems
 import time
 
+import falcon
+import six
+
 from freezer_api.api.common import resource
 from freezer_api.common import exceptions as freezer_api_exc
 from freezer_api import policy
@@ -124,7 +125,7 @@ class SessionsAction(resource.BaseResource):
         doc = self.json_body(req)
 
         try:
-            action, params = next(iteritems(doc))
+            action, params = next(six.iteritems(doc))
         except Exception:
             raise freezer_api_exc.BadDataFormat("Bad action request format")
 
@@ -156,11 +157,11 @@ class Session(resource.BaseResource):
 
     @property
     def session_tag(self):
-        return int(self.doc.get('session_tag', 0))
+        return self.doc.get('session_tag', 0)
 
     @session_tag.setter
     def session_tag(self, value):
-        self.doc['session_tag'] = int(value)
+        self.doc['session_tag'] = value
 
     def execute_action(self, action, params):
         if action == 'start':
@@ -205,15 +206,11 @@ class Session(resource.BaseResource):
         and sets the need_update member to notify that the stored
         document needs to be updated
         """
-        job_tag = int(job_tag)
-        self.session_tag = int(self.session_tag)
         now = int(time.time())
         time_since_last_start = now - self.doc.get('time_start', 0)
 
         if job_tag > self.session_tag:
-            raise freezer_api_exc.BadDataFormat(
-                'requested tag value too high. Session Tag: {0} '
-                'Job Tag: {1}'.format(self.session_tag, job_tag))
+            raise freezer_api_exc.BadDataFormat('requested tag value too high')
 
         if time_since_last_start <= self.doc.get('hold_off', 60):
             # session has been started not so long ago
